"""
This is a module that will destructively insert cats into your source code at run time.
"""
import os
import random
import threading
import time
import sys

__version__ = '0.1.4'


CURRENT_DIR = os.path.dirname(os.path.realpath(__file__))


def generate_cats():
    """
    A generator that returns ASCII cats.
    """
    with open(os.path.join(CURRENT_DIR, 'ascii_catzzz.txt')) as fd:
        ascii_catzzz_lines = fd.readlines()

        cat_lines = []
        for line in ascii_catzzz_lines:
            if not line.strip():
                yield ''.join(cat_lines)
                cat_lines = []
            else:
                cat_lines.append(line)


def print_dem_catzzz():
    """
    A callable to print all of the cats.
    """
    cat_gen = generate_cats()
    for cat in cat_gen:
        time.sleep(random.randint(5, 15))
        print('\n' + cat)
    del sys.modules['catzzz']


# Start printing cats.
thread = threading.Thread(target=print_dem_catzzz)
thread.daemon = True
thread.start()


#! /usr/bin/env python

import os
import re

from setuptools import setup


CURRENT_DIR = os.path.dirname(os.path.realpath(__file__))


with open(os.path.join(CURRENT_DIR, "README.rst")) as file:
    README = file.read()

with open(os.path.join(CURRENT_DIR, 'LICENSE')) as file:
    LICENSE = file.read()

with open(os.path.join(CURRENT_DIR, 'catzzz', '__init__.py')) as file:
    version_line = ''
    for line in file.readlines():
        if '__version__' in line:
            version_line = line
            break

    version_line = version_line.strip()

    match = re.match("__version__ = '(\d+\.\d+\.\d+)'", version_line)

    if not match:
        raise ValueError('No catzzz version info found.')

    version = match.group(1)


CLASSIFIERS = [
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Programming Language :: Python'
]


setup(name='catzzz',
      version=version,
      author='Paul Logston',
      author_email='code@logston.me',
      url='http://github.com/logston/catzzz',
      description='A package for getting more cats into your code.',
      long_description=README,
      license=LICENSE,
      classifiers=CLASSIFIERS,
      packages=['catzzz'],
      include_package_data=True,
      package_data={'': ['LICENSE', 'README.rst']})